# zencode

z3-assisted x86 shellcode encoder 

Currently it's a rather unpolished implementation with plenty of room for improvement.

## ToDo

In no particular order:

- alphanumeric encoding
- linting/style
- print resulting bytes (ready for usage) along with size, etc
- tests
- x86\_64 support
